@@ -55,7 +55,7 @@
 # univariateModels(cached statistics for the univariate indepence test), hash(hash booleab), stat_hash(hash object), 
 # output of each test: LIST of the generated pvalue, stat, flag and the updated hash objects.
 SES = function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini = NULL, wei = NULL, user_test = NULL, 
-               hash = FALSE, hashObject = NULL, ncores = 1) {
+               hash = FALSE, hashObject = NULL, ncores = 1, backward = FALSE) {
   ##############################
   # initialization part of SES #
   ##############################
@@ -289,9 +289,24 @@ SES = function(target, dataset, max_k = 3, threshold = 0.05 , test = NULL, ini =
   #call the main SES function after the checks and the initializations
   results = InternalSES(target, dataset, max_k, log(threshold), test, ini, wei, user_test, hash, varsize, stat_hash, pvalue_hash, 
                         targetID, ncores = ncores);
+  
+  varsToIterate <- results$selectedVarsOrder
+  
+  if ( backward  & length( varsToIterate ) > 0  ) {
+    varsOrder <- results$selectedVarsOrder
+    bc <- mmpcbackphase(target, dataset[, varsToIterate, drop = FALSE], test = test, wei = wei, max_k = max_k, threshold = threshold)
+    met <- bc$met
+    results$selectedVars <- varsOrder[met]
+    results$selectedVarsOrder = varsOrder[met]
+    results$signatures <- results$signatures[, met, drop = FALSE]
+    results$pvalues[varsToIterate] <- bc$pvalue
+    results$n.tests <- results$n.tests + bc$counter
+  }
+  
   SESoutput <- new("SESoutput", selectedVars = results$selectedVars, selectedVarsOrder=results$selectedVarsOrder, queues=results$queues, 
-                   signatures=results$signatures, hashObject=results$hashObject, pvalues=results$pvalues, stats=results$stats, univ = results$univ,
-                   max_k=results$max_k, threshold = results$threshold, n.tests = results$n.tests, runtime=results$runtime, test=ci_test);
+                   signatures=results$signatures, hashObject=results$hashObject, pvalues=results$pvalues, stats=results$stats, 
+                   univ = results$univ, max_k=results$max_k, threshold = results$threshold, n.tests = results$n.tests, 
+                   runtime=results$runtime, test=ci_test);
   return(SESoutput);
 }
 
