@@ -36,8 +36,8 @@ beta.mod <- function(target, dataset, wei = NULL, xnew = NULL) {
      if ( !is.null(xnew) ) {
        xnew <- model.matrix(~., data.frame(xnew) )
        est <- exp( as.vector( xnew %*% be[, 1] ) )
-     } else  est <- exp( as.vector( x %*% be[, 1]) )
-     est <- est / (1 + est)
+       est <- est / (1 + est)
+     } else  est <- NULL
      res <- list(be = be, phi = exp(mod2$par[1]), loglik = - mod2$value - sly2, est = est)      
    }
    res
