@@ -27,17 +27,25 @@ censIndER = function(target, dataset, xIndex, csIndex, wei = NULL, univariateMod
   numCases = dim(dataset)[1];
   if (length(event) == 0)  event = vector('numeric',numCases) + 1;
       if (is.na(csIndex) || length(csIndex) == 0 || csIndex == 0) {
-        expo_results <- survival::survreg(target ~ x, dist = "exponential", weights = wei)
-        dof <- length( coef(expo_results) ) - 1
-        stat = 2 * abs( diff(expo_results$loglik) )
-        pvalue = pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE);
+        expo_results <- try( survival::survreg(target ~ x, dist = "exponential", weights = wei), silent = TRUE )
+        if ( identical( class(expo_results), "try-error" ) ) {
+          stat <- NA  
+        } else {  
+          dof <- length( coef(expo_results) ) - 1
+          stat = 2 * abs( diff(expo_results$loglik) )
+          pvalue = pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE);
+        }  
       } else {
-        expo_results <- survival::survreg(target ~ ., data = as.data.frame( dataset[ , c(csIndex)] ), dist = "exponential", weights = wei) 
-        expo_results_full <- survival::survreg(target ~ ., data = as.data.frame(  dataset[ , c(csIndex, xIndex)] ), dist = "exponential", weights = wei )
-        res = anova(expo_results, expo_results_full)
-        stat = abs( res[2, 6] );
-        dF = abs( res[2, 5] );
-        pvalue = pchisq(stat, dF, lower.tail = FALSE, log.p = TRUE)
+        expo_results <- try( survival::survreg(target ~ ., data = as.data.frame( dataset[ , c(csIndex)] ), dist = "exponential", weights = wei), silent = TRUE) 
+        expo_results_full <- try( survival::survreg(target ~ ., data = as.data.frame(  dataset[ , c(csIndex, xIndex)] ), dist = "exponential", weights = wei ), silent = TRUE)
+        if ( identical( class(expo_results), "try-error" )  |  identical( class(expo_results_full), "try-error" ) ) {
+          stat <- NA
+        } else {  
+          res = anova(expo_results, expo_results_full) 
+          stat = abs( res[2, 6] );
+          dof = abs( res[2, 5] );
+          pvalue = pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE)
+        }  
       }  
       if ( is.na(pvalue) || is.na(stat) ) {
         pvalue = log(1);
