@@ -1,4 +1,4 @@
-ebic.fbed.beta <- function(y, x, gam = NULL, wei = NULL, K = 0) { 
+ebic.fbed.beta <- function(y, x, univ = NULL, gam = NULL, wei = NULL, K = 0) { 
   dm <- dim(x)
   n <- dm[1]
   p <- dm[2]
@@ -10,20 +10,26 @@ ebic.fbed.beta <- function(y, x, gam = NULL, wei = NULL, K = 0) {
   
   if ( is.null(gam) ) {
     con <- 2 - log(p) / log(n)
-    if ( (con) < 0 )  con <- 0
   } else con <- 2 * gam
+  if ( con < 0 )  con <- 0
+  
   if ( is.null(wei) ) {
     lik1 <-  - 2 * Rfast::beta.mle(y)$loglik + 2 * logn 
   } else lik1 <-  - 2 * betamle.wei(y, wei)$loglik + 2 * logn 
 
   runtime <- proc.time()
   
-  for ( i in ind ) {
-    fit2 <- beta.reg( y, x[, i], wei = wei ) 
-    lik2[i] <-  -2 * fit2$loglik + (length(fit2$be) + 1) * logn + con * log(p)
-  }
-  n.tests <- p
-  stat <- lik1 - lik2
+  if ( is.null(univ) ) {
+    lik2 <- beta.regs( y, x[, i], wei = wei, check = TRUE )[, 3] + con * log(p)
+    n.tests <- p
+    univ <- list()
+    univ$ebic <- lik2
+    stat <- lik1 - lik2
+  } else {
+    n.tests <- 0
+    lik2 <- univ$ebic
+    stat <- lik1 - lik2
+  }  
   s <- which(stat > 0)
 
     if ( length(s) > 0 ) {
@@ -183,9 +189,9 @@ ebic.fbed.beta <- function(y, x, gam = NULL, wei = NULL, K = 0) {
     res <- matrix(c(0, 0), ncol = 2)
     info <- matrix(c(0, p), ncol = 2)
   }  
-  colnames(res) <- c("Vars", "eBIC")
+  colnames(res) <- c("Vars", "eBIC difference")
   rownames(info) <- paste("K=", 1:length(card)- 1, sep = "")
   colnames(info) <- c("Number of vars", "Number of tests")
-  list(res = res, info = info, runtime = runtime)
+  list(univ = univ, res = res, info = info, runtime = runtime)
 }
  
\ No newline at end of file
