@@ -1,4 +1,4 @@
-glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FALSE, robust = FALSE) {
+glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, test = NULL) {
   
   threshold <- log(threshold)
   dm <- dim(dataset)
@@ -33,44 +33,36 @@ glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FAL
       }
     }
     dataset <- as.data.frame(dataset)
+    
+    if ( is.null(test) ) {
+      if ( is.matrix(target) )  {
+        test =="testIndBinom" 
+      } else if ( is.factor(target)  |  length( unique(target) ) == 2 ) {
+        ci_test <- test <- "testIndLogistic"
+      } else if ( length( unique(target) ) > 2  ) {
+        if ( sum( round(target) - target ) == 0 ) {
+          ci_test <- test <- "testIndPois"
+        } else  ci_test <- test <- "testIndReg"  
+      }
+    }
     ##################################
     # target checking and initialize #
     ################################## 
-    if ( is.matrix(target)  &  NCOL(target) == 2 )  {
+    if ( test == "testIndBinom" )  {
       
       ci_test <- "testIndBinom"
       wei <- target[, 2]
       ywei <- target[, 1] / wei
       
       tic <- proc.time()
-      if ( !heavy ) {
-        ini <- glm( ywei ~., data = dataset, family = binomial(logit), weights = wei, y = FALSE, model = FALSE )
-        tab <- drop1( ini, test = "Chisq" )
-        dof <- tab[-1, 1]
-        stat <- tab[-1, 4]
-        
-      }  else {
-        ci_test <- "testIndSpeedglm"
-        ini <- speedglm::speedglm( ywei ~., data = dataset, family = binomial(logit), weights = wei )
-        dofini <- length( coef(ini) )
-        stat <- dof <- numeric(p)
-		    if (p == 1) {
-          mod <- speedglm::speedglm( ywei ~ 1, data = dataset, family = binomial(logit), weights = wei )
-          stat <- mod$deviance - ini$deviance
-          dof <- dofini - length( coef(mod) ) 
-		    } else {
-          for (i in 1:p) {
-            mod <- speedglm::speedglm( ywei ~.,  data = dataset[, -i, drop = FALSE], family = binomial(logit), weights = wei )
-            stat[i] <- mod$deviance - ini$deviance
-            dof[i] <- dofini - length( coef(mod) ) 
-          } 
-		    } 
-      }	
-      
+      ini <- glm( ywei ~., data = dataset, family = binomial(logit), weights = wei, y = FALSE, model = FALSE )
+      tab <- drop1( ini, test = "Chisq" )
+      dof <- tab[-1, 1]
+      stat <- tab[-1, 4]
+
       mat <- cbind(1:p, pchisq( stat, dof, lower.tail = FALSE, log.p = TRUE), stat )
       colnames(mat) <- c("variable", "log.p-values", "statistic" )
       rownames(mat) <- 1:p 
-      
       sel <- which.max( mat[, 2] )
       info <- matrix( c(0, -10, -10) , ncol = 3 )
       sela <- sel 
@@ -87,8 +79,6 @@ glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FAL
       i <- 1  
       if ( info[1, 2] > threshold & dim(mat)[1] > 0 ) {
         
-        if ( !heavy ) {
-          
           while ( info[i, 2] > threshold  &  dim(dat)[2] > 0 )  {   
             
             ini <- glm( ywei ~., data = dat, family = binomial(logit), weights = wei, y = FALSE, model = FALSE )
@@ -129,119 +119,44 @@ glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FAL
            }  
           }
           
-        } else {
-          
-          while ( info[i, 2] > threshold  &  dim(dat)[2] > 0 )  {   
-            
-            i <- i + 1       
-            k <- p - i + 1
-            ini <- speedglm::speedglm( ywei ~., data = dat, family = binomial(logit), weights = wei )
-            dofini <- length( coef(ini) ) 
-            
-            if ( k == 1 ) {
-              mod <- speedglm::speedglm(ywei ~ 1, data = dat, family = binomial(logit), weights = wei)
-              stat <- 2 * ( logLik(ini) - logLik(mod) )
-              dof <- dofini - length( coef(mod) ) 
-              pval <- pchisq( stat, dof, lower.tail = FALSE, log.p = TRUE)
-              
-              if (pval > threshold ) {
-                final <- "No variables were selected"
-                info <- rbind(info, c(mat[, 1], pval, stat) )
-                dat <- dataset[, -info[, 1], drop = FALSE ]
-                mat <- NULL
-              } else {
-                info <- rbind(info, c(0, -10, -10)) 
-                final <- ini
-                mat[, 2:3] <- c(pval, stat)
-              }
-              
-            } else {
-              
-             stat <- dof <- numeric(k)
-             for (j in 1:k) {
-              mod <- speedglm::speedglm( ywei ~., data = dat[, -j, drop = FALSE], family = binomial(logit), weights = wei )
-              stat[j] <- mod$deviance - ini$deviance
-              dof[j] <- dofini - length( coef(mod) ) 		   
-            } 
-            
-            mat[, 2:3] <- cbind( pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE), stat )
-            sel <- which.max( mat[, 2] )
-
-            if ( mat[sel, 2] < threshold ) {
-              final <- ini
-              info <- rbind(info, c(0, -10, -10) )
-              
-            } else {
-              
-              info <- rbind(info, mat[sel, ] )
-              mat <- mat[-sel, , drop = FALSE] 
-              dat <- dataset[, -info[, 1], drop = FALSE ]
-            }
-            
-           }	
-         }    
-          
-        }
         runtime <- proc.time() - tic		
         info <- info[ info[, 1] > 0, , drop = FALSE]
         res <- list(runtime = runtime, info = info, mat = mat, ci_test = ci_test, final = final ) 
         
       }  else {
         runtime <- proc.time() - tic
-        if (ci_test == "testIndLogistic")   mod <- glm(ywei ~ 1, binomial)
+        if (ci_test == "testIndBinom")   mod <- glm(ywei ~ 1, binomial)
         res <- list(runtime = runtime, info = info, mat = NULL, ci_test = ci_test, final = mod ) 
       }
       
       }   
       
-    } else {  
+    } else {
 
    ############ 
    ###  Poisson or logistic regression
-   ############
-   	la <- length( unique(target) ) 
+   ###########
 	
-    if ( la == 2  || ( la > 2  &  sum( round(target) - target ) == 0 ) ) {
+    if ( test == "testIndLogistic" | test == "testIndPois" ) {
 
 	    tic <- proc.time()
 
-      if ( la == 2 ) {
+      if ( length( unique(target) ) == 2 ) {
         oiko <- binomial(logit)
         ci_test <- "testIndLogistic"
         
-      } else if ( la > 2  &  sum( round(target) - target ) == 0 ) {
+      } else if ( length( unique(target) )  > 2  &  sum( round(target) - target ) == 0 ) {
         oiko <- poisson(log)
         ci_test <- "testIndPois"
       }
-   
-      if ( !heavy ) {
-        ini <- glm( target ~.,  data = dataset, family = oiko, weights = wei, y = FALSE, model = FALSE )
-        tab <- drop1( ini, test = "Chisq" )
-        dof <- tab[-1, 1]
-        stat <- tab[-1, 4]
-		
-	  }  else {
-	     ci_test <- "testIndSpeedglm"
-       ini <- speedglm::speedglm( target ~.,  data = dataset, family = oiko, weights = wei )
-		   dofini <- length( coef(ini) )
-	     stat <- dof <- numeric(p)
-		   if (p == 1) {
-		     mod <- speedglm::speedglm( target ~ 1, data = dataset, family = oiko, weights = wei )
-		     stat <- mod$deviance - ini$deviance
-		     dof <- dofini - length( coef(mod) ) 		 
-		   } else {
-	       for (i in 1:p) {
-		       mod <- speedglm::speedglm( target ~.,  data = dataset[, -i, drop = FALSE], family = oiko, weights = wei )
-		       stat[i] <- mod$deviance - ini$deviance
-		       dof[i] <- dofini - length( coef(mod) ) 
-		     }
-		   }  
-	  }	
-	  
+      ini <- glm( target ~.,  data = dataset, family = oiko, weights = wei, y = FALSE, model = FALSE )
+      tab <- drop1( ini, test = "Chisq" )
+      dof <- tab[-1, 1]
+      stat <- tab[-1, 4]
+      
       mat <- cbind(1:p, pchisq( stat, dof, lower.tail = FALSE, log.p = TRUE), stat )
       colnames(mat) <- c("variable", "log.p-values", "statistic" )
       rownames(mat) <- 1:p 
-
       sel <- which.max( mat[, 2] )
       info <- matrix( c(0, -10, -10) , ncol = 3 )
       sela <- sel 
@@ -260,8 +175,6 @@ glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FAL
 
       if ( info[1, 2] > threshold  &  dim(mat)[1] > 0 ) {
         
-       if ( !heavy ) {
-	   
          while ( info[i, 2] > threshold  &  dim(dat)[2] > 0 )  {   
            i <- i + 1
            k <- p - i + 1
@@ -303,57 +216,7 @@ glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FAL
              }
            }  
          }
-         
-	   } else {
 
-         while ( info[i, 2] > threshold  &  dim(dat)[2] > 0 )  {   
-
-           i <- i + 1       
-           k <- p - i + 1
-           ini <- speedglm::speedglm( target ~., data = dat, family = oiko, weights = wei )
-		       dofini <- length( coef(ini) ) 
-		       if ( k == 1 ) {
-		         mod <- speedglm::speedglm(target ~ 1, data = dat, family = oiko, weights = wei)
-		         stat <- 2 * ( logLik(ini) - logLik(mod) )
-		         dof <- dofini - length( coef(mod) ) 
-		         pval <- pchisq( stat, dof, lower.tail = FALSE, log.p = TRUE)
-		         
-		         if (pval > threshold ) {
-		           final <- "No variables were selected"
-		           info <- rbind(info, c(mat[, 1], pval, stat) )
-		           dat <- dataset[, -info[, 1], drop = FALSE ]
-		           mat <- NULL
-		         } else {
-		           info <- rbind(info, c(0, -10, -10)) 
-		           final <- ini
-		           mat[, 2:3] <- c(pval, stat)
-		         }  
-		       } else {		       
-		       
-             stat <- dof <- numeric(k)
-		   
-		         for (j in 1:k) {
-               mod <- speedglm::speedglm( target ~., data = dat[, -j, drop = FALSE], family = oiko, weights = wei )
-		           stat[j] <- mod$deviance - ini$deviance
-		           dof[j] <- dofini - length( coef(mod) ) 		   
-		        } 
-
-             mat[, 2:3] <- cbind( pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE), stat )
-             sel <- which.max( mat[, 2] )
-      
-             if ( mat[sel, 2] < threshold ) {
-               final <- ini
-               info <- rbind(info, c(0, -10, -10) )
-
-             } else {
-               info <- rbind(info, mat[sel, ] )
-               mat <- mat[-sel, , drop = FALSE] 
-               dat <- dataset[, -info[, 1], drop = FALSE]
-             }
-
-          }	   
-        }
-	   }
       runtime <- proc.time() - tic		
       info <- info[ info[, 1] > 0, , drop = FALSE]
       res <- list(runtime = runtime, info = info, mat = mat, ci_test = ci_test, final = final ) 
@@ -372,61 +235,16 @@ glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FAL
     } else { 
       
 	    tic <- proc.time()
-
-	  if ( !heavy ) {
-	  
-	    ci_test <- "testIndReg"  
-      if ( !robust ) {
+      if (test == "testIndReg")  {
+        ci_test <- "testIndReg"
+	    
         ini <- lm( target ~., data = dataset, weights = wei, y = FALSE, model = FALSE )
         df2 <- n - length( coef(ini) )
         tab <- drop1( ini, test = "F" )
         df1 <- tab[-1, 1]
         stat <- tab[-1, 5]
         mat <- cbind(1:p, pf( stat, df1, df2, lower.tail = FALSE, log.p = TRUE), stat )
-      } else {
-	    	mat <- matrix(ncol = 3, nrow = p)
-	      mat[, 1] <- 1:p
-        ini <- MASS::rlm( target ~., data = dataset, weights = wei, maxit = 2000)
-		    lik1 <- as.numeric( logLik(ini) )
-		    dofini <- length( coef(ini) ) 
-			  if (p == 1) {
-			    fit2 <- MASS::rlm( target ~ 1, data = dataset, weights = wei, maxit = 2000 )
-          mat[1, 3] <- 2 * abs( lik1 - as.numeric( logLik(fit2) ) ) 
-		      dof <- dofini - length( coef(fit2) )
-          mat[1, 2] = pchisq( mat[1, 3], dof, lower.tail = FALSE, log.p = TRUE )  
-			  } else {
-		      for (j in 1:p) {
-            fit2 <- MASS::rlm( target ~., data = dataset[, -j, drop = FALSE], weights = wei, maxit = 2000 )
-            mat[j, 3] <- 2 * abs( lik1 - as.numeric( logLik(fit2) ) ) 
-		        dof <- dofini - length( coef(fit2) )
-            mat[j, 2] = pchisq( mat[j, 3], dof, lower.tail = FALSE, log.p = TRUE )  
-		      }
-        }			
-	    }
-	  
-    } else {
-      ci_test <- "testIndSpeedglm"
-	    mat <- matrix(ncol = 3, nrow = p)
-	    mat[, 1] <- 1:p
-      ini <- speedglm::speedlm( target ~., data = dataset, weights = wei )
-      d1 <- length( coef(ini) )
-	  if (p == 1) {
-	      fit2 = speedglm::speedlm( target ~ 1, data = dataset, weights = wei )
-          df1 = d1 - length( coef(fit2) )
-          df2 = n - d1
-          mat[1, 3] = (fit2$RSS - ini$RSS)/df1 / ( ini$RSS /df2 )
-          mat[1, 2] = pf( mat[1, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-	  } else {
-	    for (j in 1:p) {
-          fit2 = speedglm::speedlm( target ~., data = dataset[, -j, drop = FALSE], weights = wei )
-          df1 = d1 - length( coef(fit2) )
-          df2 = n - d1
-          mat[j, 3] = (fit2$RSS - ini$RSS)/df1 / ( ini$RSS /df2 )
-          mat[j, 2] = pf( mat[j, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-        }  
-       }		
-	  }
-	  
+
       colnames(mat) <- c("variable", "log.p-values", "statistic" )
       rownames(mat) <- 1:p 
 
@@ -447,13 +265,10 @@ glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FAL
 
       if ( info[1, 2] > threshold & dim(mat)[1] > 0 ) {
 
-        if ( !heavy ) {
-      
           while ( info[i, 2] > threshold  &  dim(dat)[2] > 0 )  {   
             i <- i + 1
             k <- p - i + 1
             
-	        if ( !robust ) {
             ini <- lm( target ~.,  data = dat, weights = wei, y = FALSE, model = FALSE )
             df2 <- n - length( coef(ini) )
             tab <- drop1( ini, test = "F" )
@@ -480,110 +295,14 @@ glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FAL
               if ( mat[sel, 2] < threshold ) {
                 final <- ini
                 info <- rbind(info, c(0, -10, -10) )
-                
               } else {
-                
                 info <- rbind(info, mat[sel, ] )
                 mat <- mat[-sel, , drop = FALSE] 
                 dat <- dataset[, -info[, 1], drop = FALSE] 
-              }
-            }
+              }  ## end if ( mat[sel, 2] < threshold )
+            }  ## end if ( k == 1 )
             
-			    } else {
-            ini <- MASS::rlm( target ~., data = dat, weights = wei, maxit = 2000 )
-			      lik1 <- as.numeric( logLik(ini) )
-            dofini <- length( coef(ini) )		
-            
-            if ( k == 1 ) {
-              mod <- MASS::rlm(target ~ 1, data = dat, weights = wei, maxit = 2000)
-              stat <- 2 * abs( lik1 - logLik(mod) )
-              dof <- dofini - length( coef(mod) ) 
-              pval <- pchisq( stat, dof, lower.tail = FALSE, log.p = TRUE)
-              
-              if (pval > threshold ) {
-                final <- "No variables were selected"
-                info <- rbind(info, c(mat[, 1], pval, stat) )
-                dat <- dataset[, -info[, 1], drop = FALSE ]
-                mat <- NULL
-              } else {
-                info <- rbind(info, c(0, -10, -10)) 
-                final <- ini
-                mat[, 2:3] <- c(pval, stat)
-              }  
-            } else { 
-            
-			        for (j in 1:k) {
-                fit2 <- MASS::rlm( target ~., data = dat[, -j, drop = FALSE], weights = wei, maxit = 2000 )
-                mat[j, 3] <- 2 * abs( lik1 - as.numeric( logLik(fit2) ) ) 
-		            dof <- dofini - length( coef(fit2) )
-                mat[j, 2] <- pchisq( mat[j, 3], dof, lower.tail = FALSE, log.p = TRUE )  
-		          }  
-            
-              sel <- which.max( mat[, 2] )
-              if ( mat[sel, 2] < threshold ) {
-			          final <- ini
-                info <- rbind(info, c(0, -10, -10) )
-
-              } else {
-      
-                info <- rbind(info, mat[sel, ] )
-                mat <- mat[-sel, , drop = FALSE] 
-                dat <- dataset[, -info[, 1] ,drop = FALSE]
-              }
-			      }
-          } 
-         }
-          
-        } else {
-
-          while ( info[i, 2] > threshold  &  dim(dat)[2] > 0 )  {   
-            
-            i <- i + 1
-            k <- p - i + 1
-            ini <- speedglm::speedlm( target ~.,  data = dat, weights = wei )	
-            d1 <- length( coef(ini) )
-            
-            if ( k == 1 ) {
-              mod <- speedglm::speedlm(target ~ 1, data = dat, weights = wei)
-              stat <- (mod$RSS - ini$RSS)/d1 / ( ini$RSS /(n - d1) )
-              pval <- pf( stat, d1 - 1, n - d1, lower.tail = FALSE, log.p = TRUE )
-              
-              if (pval > threshold ) {
-                final <- "No variables were selected"
-                info <- rbind(info, c(mat[, 1], pval, stat) )
-                dat <- as.data.frame( dataset[, -info[, 1] ] )
-                mat <- NULL
-              } else {
-                info <- rbind(info, c(0, -10, -10)) 
-                final <- ini
-                mat[, 2:3] <- c(pval, stat)
-              }  
-            } else {
-              
-   	          for (j in 1:k) {
-                fit2 = speedglm::speedlm( target ~., data = dat[, -j, drop = FALSE], weights = wei )
-                df1 = d1 - length( coef(fit2) )
-                df2 = n - d1
-                mat[j, 3] = (fit2$RSS - ini$RSS)/df1 / ( ini$RSS /df2 )
-                mat[j, 2] = pf( mat[j, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-              }    		  
-
-              sel <- which.max( mat[, 2] )
-
-              if ( mat[sel, 2] < threshold ) {
-                final <- ini
-                info <- rbind(info, c(0, -10, -10) )
-
-              } else {
-                info <- rbind(info, mat[sel, ] )
-                mat <- mat[-sel, , drop = FALSE] 
-                dat <- dataset[, -info[, 1], drop = FALSE]
-              }
-
-            } 		
-          }
-          
-        }
+          }  ## end while ( info[i, 2] > threshold  &  dim(dat)[2] > 0 )
         
         runtime <- proc.time() - tic		
         info <- info[ info[, 1] > 0, , drop = FALSE]
@@ -591,13 +310,116 @@ glm.bsreg <- function(target, dataset, threshold = 0.05, wei = NULL, heavy = FAL
         
       }	else {
         runtime <- proc.time() - tic
-        if (ci_test == "testIndReg")     mod <- lm(target ~ 1, weights = wei)
+        mod <- lm(target ~ 1, weights = wei)
         res <- list(runtime = runtime, info = info, mat = NULL, ci_test = ci_test, final = mod ) 
-      }
+      }  ## end if ( info[1, 2] > threshold & dim(mat)[1] > 0 )
 
+      }  ## end if ( mat[sel, 2] < threshold )
+      
+     } else if (test == "testIndMMReg")  {
+      
+      tic <- proc.time()
+      ci_test <- "testIndMMReg"
+
+        mat <- matrix(ncol = 3, nrow = p)
+        mat[, 1] <- 1:p
+        ini <- MASS::rlm( target ~., data = dataset, method = "MM", maxit = 2000)
+        lik1 <- as.numeric( logLik(ini) )
+        dofini <- length( coef(ini) ) 
+        if (p == 1) {
+          fit2 <- MASS::rlm( target ~ 1, data = dataset, method = "MM", maxit = 2000 )
+          mat[1, 3] <- 2 * abs( lik1 - as.numeric( logLik(fit2) ) ) 
+          dof <- dofini - length( coef(fit2) )
+          mat[1, 2] = pchisq( mat[1, 3], dof, lower.tail = FALSE, log.p = TRUE )  
+        } else {
+          for (j in 1:p) {
+            fit2 <- MASS::rlm( target ~., data = dataset[, -j, drop = FALSE], method = "MM", maxit = 2000 )
+            mat[j, 3] <- 2 * abs( lik1 - as.numeric( logLik(fit2) ) ) 
+            dof <- dofini - length( coef(fit2) )
+            mat[j, 2] = pchisq( mat[j, 3], dof, lower.tail = FALSE, log.p = TRUE )  
+          }
+        }  ## end if (p == 1) 			
+      colnames(mat) <- c("variable", "log.p-values", "statistic" )
+      rownames(mat) <- 1:p 
+      sel <- which.max( mat[, 2] )
+      info <- matrix( c(0, -10, -10) , ncol = 3 )
+      sela <- sel 
+      
+      if ( mat[sel, 2] < threshold ) {
+        runtime <- proc.time() - tic
+        res <- list(runtime = runtime, info = matrix(0, 0, 3), mat = mat, ci_test = ci_test, final = ini ) 
+        
+      } else {
+        info[1, ] <- mat[sel, ]
+        mat <- mat[-sel, , drop = FALSE] 
+        dat <- dataset[, -sel, drop = FALSE] 
+        
+        i <- 1  
+        
+        if ( info[1, 2] > threshold & dim(mat)[1] > 0 ) {
+          
+          while ( info[i, 2] > threshold  &  dim(dat)[2] > 0 )  {   
+            i <- i + 1
+            k <- p - i + 1
+
+              ini <- MASS::rlm( target ~., data = dat, method = "MM", maxit = 2000 )
+              lik1 <- as.numeric( logLik(ini) )
+              dofini <- length( coef(ini) )		
+              
+              if ( k == 1 ) {
+                mod <- MASS::rlm(target ~ 1, data = dat, method = "MM", maxit = 2000)
+                stat <- 2 * abs( lik1 - logLik(mod) )
+                dof <- dofini - length( coef(mod) ) 
+                pval <- pchisq( stat, dof, lower.tail = FALSE, log.p = TRUE)
+                
+                if (pval > threshold ) {
+                  final <- "No variables were selected"
+                  info <- rbind(info, c(mat[, 1], pval, stat) )
+                  dat <- dataset[, -info[, 1], drop = FALSE ]
+                  mat <- NULL
+                } else {
+                  info <- rbind(info, c(0, -10, -10)) 
+                  final <- ini
+                  mat[, 2:3] <- c(pval, stat)
+                }  
+              } else { 
+                
+                for (j in 1:k) {
+                  fit2 <- MASS::rlm( target ~., data = dat[, -j, drop = FALSE], method = "MM", maxit = 2000 )
+                  mat[j, 3] <- 2 * abs( lik1 - as.numeric( logLik(fit2) ) ) 
+                  dof <- dofini - length( coef(fit2) )
+                  mat[j, 2] <- pchisq( mat[j, 3], dof, lower.tail = FALSE, log.p = TRUE )  
+                }  
+                
+                sel <- which.max( mat[, 2] )
+                if ( mat[sel, 2] < threshold ) {
+                  final <- ini
+                  info <- rbind(info, c(0, -10, -10) )
+                } else {
+                  info <- rbind(info, mat[sel, ] )
+                  mat <- mat[-sel, , drop = FALSE] 
+                  dat <- dataset[, -info[, 1] ,drop = FALSE]
+                }  ## end if ( mat[sel, 2] < threshold )
+              }
+          }  ## end while ( info[i, 2] > threshold  &  dim(dat)[2] > 0 ) 
+          
+          runtime <- proc.time() - tic		
+          info <- info[ info[, 1] > 0, , drop = FALSE]
+          res <- list(runtime = runtime, info = info, mat = mat, ci_test = ci_test, final = final ) 
+          
+        }	else {
+          runtime <- proc.time() - tic
+          mod <- MASS::rlm(target ~ 1, maxit = 2000, method = "MM")
+          res <- list(runtime = runtime, info = info, mat = NULL, ci_test = ci_test, final = mod ) 
+        }  ## end if ( info[1, 2] > threshold & dim(mat)[1] > 0 )
+        
+      }  ## end if ( mat[sel, 2] < threshold )
+      
       }
-     }  
+      
+     }   ## end else 
     
+      
     }
 
     
