@@ -1,49 +1,52 @@
-gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] ), test = "testIndFisher" ) {
+gomp <- function(target, dataset, tol = qchisq(0.95, 1), test = "testIndLogistic", method = "ar2") {
 
   if ( test == "testIndReg" | test == "testIndFisher" ) {
     tic <- proc.time()
-    res <- Rfast::ompr(target, dataset, method = "BIC", tol)
+    res <- Rfast::ompr(target, dataset, method = method, tol)
     runtime <- proc.time() - tic
-    result <- list(runtime = runtime, res = res)
+    result <- list(runtime = runtime, phi = NULL, res = res)
   } else if ( test == "testIndLogistic" ) {
     tic <- proc.time()
-    res <- Rfast::omp(target, dataset, tol, type = "logistic")$info
+    res <- Rfast::omp(target, dataset, tol, type = "logistic")
     runtime <- proc.time() - tic
-    result <- list(runtime = runtime, res = res)
+    result <- list(runtime = runtime, phi = NULL, res = res$info)
   } else if ( test == "testIndPois" ) {
     tic <- proc.time()
-    res <- Rfast::omp(target, dataset, tol, type = "poisson")$info
+    res <- Rfast::omp(target, dataset, tol, type = "poisson")
     runtime <- proc.time() - tic
-    result <- list(runtime = runtime, res = res)
-    
+    result <- list(runtime = runtime, phi = NULL, res = res$info)
+
   } else if ( test == "testIndQPois" ) {
-    result <- gomp2(target, dataset, tol, type = "quasipoisson")
+    tic <- proc.time()
+    res <- Rfast::omp(target, dataset, tol, type = "quasipoisson")
+    runtime <- proc.time() - tic
+    result <- list(runtime = runtime, phi = res$phi, res = res$info)
     
   } else if (test == "testIndMVreg") {	
     tic <- proc.time()
-    res <- Rfast::omp(target, dataset, tol, type = "mv")$info
+    res <- Rfast::omp(target, dataset, tol, type = "mv")
     runtime <- proc.time() - tic
-    result <- list(runtime = runtime, res = res)
+    result <- list(runtime = runtime, phi = NULL, res = res$info)
   } else if ( test == "testIndQBinom" ) {
     tic <- proc.time()
-    res <- Rfast::omp(target, dataset, tol, type = "quasibinomial")$info
+    res <- Rfast::omp(target, dataset, tol, type = "quasibinomial")
     runtime <- proc.time() - tic
-    result <- list(runtime = runtime, res = res)
+    result <- list(runtime = runtime, phi = res$phi, res = res$info)
   } else if ( test == "testIndNormLog" ) {
     tic <- proc.time()
-    res <- Rfast::omp(target, dataset, tol, type = "normlog")$info
+    res <- Rfast::omp(target, dataset, tol, type = "normlog")
     runtime <- proc.time() - tic
-    result <- list(runtime = runtime, res = res)
+    result <- list(runtime = runtime, phi = res$phi, res = res$info)
     
   } else if ( test == "testIndGamma" ) {
-    result <- gomp2(target, dataset, tol, type = "gamma")
+    result <- gomp2(target, dataset, tol, test = test)
     
   } else {
     d <- dim(dataset)[2]
     ind <- 1:d
     dataset <- Rfast::standardise(dataset)
     can <- which( is.na( Rfast::colsums(dataset) ) )
-	  ind[can] <- 0
+    ind[can] <- 0
 	
     if (test == "testIndNB") {
       tic <- proc.time()
@@ -54,22 +57,23 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
 	    sel <- which.max( abs(ela) )  
       sela <- sel
       names(sela) <- NULL
-      mod <- MASS::glm.nb(target ~ dataset[, sela])
+      mod <- MASS::glm.nb( target ~ dataset[, sela], control = list(epsilon = 1e-08, maxit = 50, trace = FALSE) )
       res <-  mod$residuals
       rho[2] <-  - 2 * as.numeric( logLik(mod) )
       ind[sel] <- 0
       i <- 2
-      r <- numeric(d)
+      r <- rep(NA, d)
       while ( (rho[i - 1] - rho[i]) > tol ) {
         i <- i + 1
-        r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        ## r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        r[ind] <- Rfast::eachcol.apply(dataset, res, indices = ind[ind > 0 ], oper = "*", apply = "sum") 
         sel <- which.max( abs(r) )
         sela <- c(sela, sel)
-        mod <- MASS::glm.nb(target ~ dataset[, sela])        
+        mod <- MASS::glm.nb( target ~ dataset[, sela], control = list(epsilon = 1e-08, maxit = 50, trace = FALSE) )        
         res <- target - fitted(mod)
         rho[i] <-  - 2 * as.numeric( logLik(mod) )
         ind[sela] <- 0
-        r[sela] <- 0
+        r[sela] <- NA
       } ## end while ( (rho[i - 1] - rho[i]) > tol )
       runtime <- proc.time() - tic
       len <- length(sela)
@@ -96,10 +100,11 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
         ind[sel] <- 0
       }  
       i <- 2
-      r <- numeric(d)
+      r <- rep(NA, d)
       while ( (rho[i - 1] - rho[i]) > tol ) {
         i <- i + 1
-        r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        ##r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        r[ind] <- Rfast::eachcol.apply(dataset, res, indices = ind[ind > 0 ], oper = "*", apply = "sum") 
         sel <- which.max( abs(r) )
         sela <- c(sela, sel)
         mod <- try( beta.reg(target, dataset[, sela]), silent = TRUE )        
@@ -110,7 +115,7 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
           res <- target - est / (1 + est)
           rho[i] <-  - 2 * mod$loglik
           ind[sela] <- 0
-          r[sela] <- 0
+          r[sela] <- NA
         }  
       } ## end while ( (rho[i - 1] - rho[i]) > tol )
       runtime <- proc.time() - tic
@@ -133,10 +138,11 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
       rho[2] <-  - 2 * as.numeric( logLik(mod) ) 
       ind[sel] <- 0
       i <- 2
-      r <- numeric(d)
+      r <- rep(NA, d)
       while ( (rho[i - 1] - rho[i]) > tol ) {
         i <- i + 1
-        r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        ##r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        r[ind] <- Rfast::eachcol.apply(dataset, res, indices = ind[ind > 0 ], oper = "*", apply = "sum") 
         sel <- which.max( abs(r) )
         sela <- c(sela, sel)
         mod <- try( MASS::rlm(target ~ dataset[, sela], method = "MM", maxit = 2000 ), silent = TRUE )
@@ -146,7 +152,7 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
           res <- mod$residuals
           rho[i] <-  - 2 * as.numeric( logLik(mod) ) 
           ind[sela] <- 0
-          r[sela] <- 0
+          r[sela] <- NA
         }  
       } ## end while ( (rho[i - 1] - rho[i]) > tol )
       runtime <- proc.time() - tic
@@ -169,10 +175,11 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
       rho[2] <-  - 2 * as.numeric( logLik(mod) ) 
       ind[sel] <- 0
       i <- 2
-      r <- numeric(d)
+      r <- rep(NA, d)
       while ( (rho[i - 1] - rho[i]) > tol ) {
         i <- i + 1
-        r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        ##r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        r[ind] <- Rfast::eachcol.apply(dataset, res, indices = ind[ind > 0 ], oper = "*", apply = "sum") 
         sel <- which.max( abs(r) )
         sela <- c(sela, sel)
         mod <- try( quantreg::rq(target ~ dataset[, sela]), silent = TRUE )
@@ -182,7 +189,7 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
           res <- mod$residuals
           rho[i] <-  - 2 * as.numeric( logLik(mod) ) 
           ind[sela] <- 0
-          r[sela] <- 0
+          r[sela] <- NA
         }  
       } ## end while ( (rho[i - 1] - rho[i]) > tol )
       runtime <- proc.time() - tic
@@ -191,6 +198,39 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
       colnames(res) <- c("Selected Vars", "Deviance") 
       result <- list(runtime = runtime, res = res)
       
+    } else if (test == "testIndOrdinal") {
+      tic <- proc.time()
+      mod <- MASS::polr(target ~ 1)
+      rho <-  - 2 * as.numeric( logLik(mod) )
+      res <- ord.resid(target, mod$fitted.values)
+      ela <- as.vector( cov(res, dataset) )
+      sel <- which.max( abs(ela) )     
+      sela <- sel
+      names(sela) <- NULL
+      mod <- MASS::polr(target ~ dataset[, sela])
+      res <- ord.resid(target, mod$fitted.values) 
+      rho[2] <-  - 2 * as.numeric( logLik(mod) )
+      ind[sel] <- 0
+      i <- 2
+      r <- rep(NA, d)
+      while ( (rho[i - 1] - rho[i]) > tol ) {
+        i <- i + 1
+        ##r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        r[ind] <- Rfast::eachcol.apply(dataset, res, indices = ind[ind > 0 ], oper = "*", apply = "sum") 
+        sel <- which.max( abs(r) )
+        sela <- c(sela, sel)
+        mod <- MASS::polr(target ~ dataset[, sela])        
+        res <- ord.resid(target, mod$fitted.values)
+        rho[i] <-  - 2 * as.numeric( logLik(mod) )
+        ind[sela] <- 0
+        r[sela] <- NA
+      } ## end while ( (rho[i - 1] - rho[i]) > tol )
+      runtime <- proc.time() - tic
+      len <- length(sela)
+      res <- cbind(c(0, sela[-len]), rho[1:len])
+      colnames(res) <- c("Selected Vars", "Deviance") 
+      result <- list(runtime = runtime, res = res)
+      
     } else if ( test == "testIndTobit") {
       tic <- proc.time()
       mod <- survival::survreg(target ~ 1, dist = "gaussian")
@@ -205,10 +245,11 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
       rho[2] <-  - 2 * as.numeric( logLik(mod) ) 
       ind[sel] <- 0
       i <- 2
-      r <- numeric(d)
+      r <- rep(NA, d)
       while ( (rho[i - 1] - rho[i]) > tol ) {
         i <- i + 1
-        r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        ##r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        r[ind] <- Rfast::eachcol.apply(dataset, res, indices = ind[ind > 0 ], oper = "*", apply = "sum") 
         sel <- which.max( abs(r) )
         sela <- c(sela, sel)
         mod <- try( survival::survreg(target ~ dataset[, sela], dist = "gaussian" ), silent = TRUE )
@@ -218,7 +259,7 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
           res <- resid(mod)
           rho[i] <-  - 2 * as.numeric( logLik(mod) ) 
           ind[sela] <- 0
-          r[sela] <- 0
+          r[sela] <- NA
         }  
       } ## end while ( (rho[i - 1] - rho[i]) > tol )
       runtime <- proc.time() - tic
@@ -241,10 +282,11 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
       rho[2] <-  - 2 * as.numeric( logLik(mod) ) 
       ind[sel] <- 0
       i <- 2
-      r <- numeric(d)
+      r <- rep(NA, d)
       while ( (rho[i - 1] - rho[i]) > tol ) {
         i <- i + 1
-        r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        ##r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        r[ind] <- Rfast::eachcol.apply(dataset, res, indices = ind[ind > 0 ], oper = "*", apply = "sum") 
         sel <- which.max( abs(r) )
         sela <- c(sela, sel)
         mod <- try( survival::coxph(target ~ dataset[, sela] ), silent = TRUE )
@@ -254,7 +296,7 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
           res <- mod$residuals   ## martingale residuals
           rho[i] <-  - 2 * as.numeric( logLik(mod) ) 
           ind[sela] <- 0
-          r[sela] <- 0
+          r[sela] <- NA
         }  
       } ## end while ( (rho[i - 1] - rho[i]) > tol )
       runtime <- proc.time() - tic
@@ -272,32 +314,34 @@ gomp <- function(target, dataset, tol = qchisq(0.95, 1) + log( dim(dataset)[1] )
       sel <- which.max( abs(ela) )  
       sela <- sel
       names(sela) <- NULL
-      mod <- survival::survreg(target ~ dataset[, sela] )
+      mod <- survival::survreg(target ~ dataset[, sela], control = list(iter.max = 5000) )
       res <- resid(mod)
       rho[2] <-  - 2 * as.numeric( logLik(mod) ) 
+      if ( is.na(rho[2]) )  rho[2] <- rho[1]
       ind[sel] <- 0
       i <- 2
-      r <- numeric(d)
+      r <- rep(NA, d)
       while ( (rho[i - 1] - rho[i]) > tol ) {
         i <- i + 1
-        r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        ##r[ind] <- Rfast::colsums( dataset[, ind, drop = FALSE] * res )
+        r[ind] <- Rfast::eachcol.apply(dataset, res, indices = ind[ind > 0 ], oper = "*", apply = "sum") 
         sel <- which.max( abs(r) )
         sela <- c(sela, sel)
-        mod <- try( survival::survreg(target ~ dataset[, sela] ), silent = TRUE )
+        mod <- try( survival::survreg(target ~ dataset[, sela], control = list(iter.max = 5000) ), silent = TRUE )
         if ( identical( class(mod), "try-error" ) ) {
           rho[i] <- rho[i - 1]
         } else {  
           res <- resid(mod)
           rho[i] <-  - 2 * as.numeric( logLik(mod) ) 
           ind[sela] <- 0  
-          r[sela] <- 0
+          r[sela] <- NA
         }  
       } ## end while ( (rho[i - 1] - rho[i]) > tol )
       runtime <- proc.time() - tic
       len <- length(sela)
       res <- cbind(c(0, sela[-len]), rho[1:len])
       colnames(res) <- c("Selected Vars", "Deviance") 
-      result <- list(runtime = runtime, res = res)
+      result <- list(runtime = runtime, phi = NULL, res = res)
     } ##  end if (test == "testIndNB")
   }  ##  end if ( test == "testIndReg" | test == "testIndfisher" ) 
   
