@@ -1,10 +1,9 @@
-permZIP = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL, univariateModels=NULL , hash = FALSE, stat_hash=NULL, pvalue_hash=NULL,
-                      robust=FALSE, threshold = 0.05, R = 999) {
+permZIP = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels=NULL , hash = FALSE, stat_hash=NULL, pvalue_hash=NULL,
+                     threshold = 0.05, R = 999) {
   #initialization
   #if the test cannot performed succesfully these are the returned values
-  pvalue = 1;
+  pvalue = log(1);
   stat = 0;
-  flag = 0;
   csIndex[ which( is.na(csIndex) ) ] = 0;
   thres <- threshold * R + 1
   
@@ -16,43 +15,39 @@ permZIP = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
     if (is.null(stat_hash[[key]]) == FALSE) {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
-  #if the xIndex is contained in csIndex, x does not bring any new
   #information with respect to cs
   if ( !is.na( match(xIndex, csIndex) ) ) {
     if (hash) { #update hash objects
       stat_hash[[key]] <- 0;     #.set(stat_hash , key , 0)
-      pvalue_hash[[key]] <- 1;     #.set(pvalue_hash , key , 1)
+      pvalue_hash[[key]] <- log(1);     #.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   #check input validity
   if (xIndex < 0 || csIndex < 0) {
     message(paste("error in testIndZIP : wrong input of xIndex or csIndex"))
-    results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
   xIndex = unique(xIndex);
   csIndex = unique(csIndex);
-  #extract the data
   x = dataset[ , xIndex];
   cs = dataset[ , csIndex];
-  #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 ) {
     if ( is.null(dim(cs)[2]) ) { #cs is a vector
       if ( identical(x, cs) ) { #if(!any(x == cs) == FALSE)
         if (hash) {#update hash objects
           stat_hash[[key]] <- 0;    #.set(stat_hash , key , 0)
-          pvalue_hash[[key]] <- 1;     #.set(pvalue_hash , key , 1)
+          pvalue_hash[[key]] <- log(1);     #.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     } else {     #more than one var
@@ -60,9 +55,9 @@ permZIP = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
         if ( identical(x, cs[, col]) ) { #if(!any(x == cs) == FALSE)
           if (hash) {     #update hash objects
             stat_hash[[key]] <- 0;     #.set(stat_hash , key , 0)
-            pvalue_hash[[key]] <- 1;     #.set(pvalue_hash , key , 1)
+            pvalue_hash[[key]] <- log(1);     #.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = 1, stat = 0, flag = 1, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
@@ -87,15 +82,14 @@ permZIP = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
             step <- step + ( bit2 > lik2 )
             j <- j + 1
           }
-          pvalue <- (step + 1) / (R + 1)         
+          pvalue <- log( log( (step + 1) / (R + 1) ))
 		}  
-        flag <- 1;
 
       } else {
         fit1 <- zip.reg(target, cs, wei = wei, lgy = lgy) 
         fit2 <- zip.reg(target, cbind(cs, x), wei = wei, lgy = lgy) 
         stat <- 2 * abs( fit2$loglik - fit1$loglik )
-		if (stat > 0) {
+		    if (stat > 0) {
           step <- 0
           j <- 1		
           while (j <= R & step < thres ) {
@@ -104,15 +98,13 @@ permZIP = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
             step <- step + ( bit2 > lik2 )
             j <- j + 1
           }
-          pvalue <- (step + 1) / (R + 1)         
+          pvalue <- log( log( (step + 1) / (R + 1) ))
 		}  
-        flag <- 1;
       } 
       #last error check
       if ( is.na(pvalue) || is.na(stat) ) {
-        pvalue = 1;
+        pvalue = log(1);
         stat = 0;
-        flag = 0;
       } else {
         #update hash objects
         if ( hash )  {
@@ -121,26 +113,14 @@ permZIP = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo=NULL,
         }
       }
       #testerrorcaseintrycatch(4);
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
       
     },
     error=function(cond) {
-      #   message(paste("error in try catch of the testIndZIP test"))
-      #   message("Here's the original error message:")
-      #   message(cond)
-      #   #        #for debug
-      #   #        print("\nxIndex = \n");
-      #   #        print(xIndex);
-      #   #        print("\ncsindex = \n");
-      #   #        print(csIndex);
-      #   stop();
-      #error case
-      pvalue = 1;
+      pvalue = log(1)
       stat = 0;
-      flag = 0;
-      
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     },
     finally={}
