@@ -84,16 +84,16 @@ testIndGEEPois = function(target, reps = NULL, group, dataset, xIndex, csIndex,
       return(results);
     }
     if ( is.null(reps) ) {
-      fit2 <- try( geepack::geeglm( target ~ dataset[, xIndex], family = poisson(log), id = group, weights = wei, corstr = correl, std.err = se ), silent = TRUE)
+      fit2 <- try( geepack::geeglm( target ~ x, family = poisson(log), id = group, weights = wei, corstr = correl, std.err = se ), silent = TRUE)
     } else {
-      fit2 <- try( geepack::geeglm( target ~ reps + dataset[, xIndex], family = poisson(log), id = group, waves = reps, weights = wei, corstr = correl, std.err = se ), silent = TRUE) 
+      fit2 <- try( geepack::geeglm( target ~ reps + x, family = poisson(log), id = group, waves = reps, weights = wei, corstr = correl, std.err = se ), silent = TRUE) 
     }
     
   } else {
     if ( is.null(reps) ) {
-      fit2 <- try( geepack::geeglm( target ~ dataset[, csIndex] + dataset[, xIndex], family = poisson(log), id = group, weights = wei, corstr = correl, std.err = se ), silent = TRUE)
+      fit2 <- try( geepack::geeglm( target ~ cs + x, family = poisson(log), id = group, weights = wei, corstr = correl, std.err = se ), silent = TRUE)
     } else {
-      fit2 <- try( geepack::geeglm( target ~ reps + dataset[, csIndex] + dataset[, xIndex], family = poisson(log), id = group, waves = reps, weights = wei, corstr = correl, std.err = se ), silent = TRUE) 
+      fit2 <- try( geepack::geeglm( target ~ reps + cs + x, family = poisson(log), id = group, waves = reps, weights = wei, corstr = correl, std.err = se ), silent = TRUE) 
     }  
   }
   #calculate the p value and stat.
