@@ -85,31 +85,31 @@ testIndGLMMGamma = function(target, reps = NULL, group, dataset, xIndex, csIndex
     }
     if ( is.null(reps) ) {
       fit1 = lme4::glmer( target ~ (1|group), weights = wei, family = Gamma(log) ) 
-      fit2 = lme4::glmer( target ~ (1|group) + dataset[, xIndex], weights = wei, family = Gamma(log) ) 
+      fit2 = lme4::glmer( target ~ (1|group) + x, weights = wei, family = Gamma(log) ) 
     } else {
       reps <- reps 
       if ( slopes ) {
         fit1 = lme4::glmer( target ~ reps + (reps|group), weights = wei, family = Gamma(log) ) 
-        fit2 = lme4::glmer( target ~ reps + (reps|group) + dataset[, xIndex], weights = wei, family = Gamma(log) ) 
+        fit2 = lme4::glmer( target ~ reps + (reps|group) + x, weights = wei, family = Gamma(log) ) 
       } else {
         reps = reps 
         fit1 = lme4::glmer( target ~ reps + (1|group), weights = wei, family = Gamma(log) )  
-        fit2 = lme4::glmer( target ~ reps + (1|group) + dataset[, xIndex], weights = wei, family = Gamma(log) )  
+        fit2 = lme4::glmer( target ~ reps + (1|group) + x, weights = wei, family = Gamma(log) )  
       }
     }
     
   } else {
     if ( is.null(reps) ) {
-      fit1 = lme4::glmer( target ~ (1|group) + dataset[, csIndex], weights = wei, family = Gamma(log) )    
-      fit2 = lme4::glmer( target ~ (1|group) + dataset[, csIndex] + dataset[, xIndex], weights = wei, family = Gamma(log) )    
+      fit1 = lme4::glmer( target ~ (1|group) + cs, weights = wei, family = Gamma(log) )    
+      fit2 = lme4::glmer( target ~ (1|group) + cs + x, weights = wei, family = Gamma(log) )    
     } else {
       reps = reps 
       if (slopes ) {
-        fit1 = lme4::glmer( target ~ reps + (reps|group) + dataset[, csIndex], weights = wei, family = Gamma(log))
-        fit2 = lme4::glmer( target ~ reps + (reps|group) + dataset[, csIndex] + dataset[, xIndex], weights = wei, family = Gamma(log) )
+        fit1 = lme4::glmer( target ~ reps + (reps|group) + cs, weights = wei, family = Gamma(log))
+        fit2 = lme4::glmer( target ~ reps + (reps|group) + cs + x, weights = wei, family = Gamma(log) )
       } else {
-        fit1 = lme4::glmer( target ~ reps + (1|group) + dataset[, csIndex], weights = wei, family = Gamma(log)) 
-        fit2 = lme4::glmer( target ~ reps + (1|group) + dataset[, csIndex] + dataset[, xIndex], weights = wei, family = Gamma(log) ) 
+        fit1 = lme4::glmer( target ~ reps + (1|group) + cs, weights = wei, family = Gamma(log)) 
+        fit2 = lme4::glmer( target ~ reps + (1|group) + cs + x, weights = wei, family = Gamma(log) ) 
       }
     }  
   }
