@@ -82,7 +82,7 @@ testIndNormLog = function(target, dataset, xIndex, csIndex, wei = NULL, univaria
     fit1 = glm(target ~ 1, family = gaussian(link = log), weights = wei, model = FALSE)
     fit2 = glm(target ~ x, family = gaussian(link = log), weights = wei, model = FALSE) 
   } else {
-    fit1 = glm(target ~., data = as.data.frame( dataset[, csIndex] ), family = gaussian(link = log), weights = wei, model = FALSE)
+    fit1 = glm(target ~., data = as.data.frame( cs ), family = gaussian(link = log), weights = wei, model = FALSE)
     fit2 = glm(target ~., data = as.data.frame( dataset[, c(csIndex, xIndex)] ), family = gaussian(link = log), weights = wei, model = FALSE)
   } 
   mod <- anova(fit1, fit2, test = "F")
