@@ -21,14 +21,13 @@ testIndTobit = function(target, dataset, xIndex, csIndex, wei = NULL, univariate
   tob = NULL;
   tob_full = NULL;
   #if the censored indicator is empty, a dummy variable is created
-  numCases = dim(dataset)[1];
   if (is.na(csIndex) || length(csIndex) == 0 || csIndex == 0) {
-    tob <- survival::survreg(target ~ dataset[ , xIndex], weights = wei, dist = "gaussian")
+    tob <- survival::survreg(target ~ x, weights = wei, dist = "gaussian")
     dof <- length( coef(tob) ) - 1
     stat = 2 * abs( diff(tob$loglik) )
     pvalue = pchisq(stat, dof, lower.tail = FALSE, log.p = TRUE);
   } else {
-    tob <- survival::survreg(target ~ ., data = as.data.frame( dataset[ , c(csIndex)] ), weights = wei, dist = "gaussian") 
+    tob <- survival::survreg(target ~ ., data = as.data.frame( dataset[ , c(csIndex, xIndex)] ), weights = wei, dist = "gaussian") 
     tob_full <- survival::survreg(target ~ ., data = as.data.frame(  dataset[ , c(csIndex, xIndex)] ), weights = wei, dist = "gaussian")
     res = anova(tob, tob_full)
     stat = res[2, 6] ;
