@@ -1,10 +1,9 @@
-waldGamma = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NULL, univariateModels = NULL , hash = FALSE, stat_hash = NULL, pvalue_hash = NULL,robust = FALSE) 
+waldGamma = function(target, dataset, xIndex, csIndex, wei = NULL, univariateModels = NULL , hash = FALSE, stat_hash = NULL, pvalue_hash = NULL) 
 {
   ## initialization
   #if the test cannot performed succesfully these are the returned values
   pvalue = log(1);
   stat = 0;
-  flag = 0;
   csIndex[ which( is.na(csIndex) ) ] = 0;
   if ( hash )  {
     csIndex2 = csIndex[which(csIndex!=0)]
@@ -14,8 +13,7 @@ waldGamma = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
     if ( !is.null(stat_hash[[key]]) )  {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
-      flag = 1;
-      results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+      results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
       return(results);
     }
   }
@@ -26,22 +24,20 @@ waldGamma = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
       stat_hash[[key]] <- 0;     #.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);      #.set(pvalue_hash , key , 1)
     }
-    results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   #check input validity
   if(xIndex < 0 || csIndex < 0)  {
     message(paste("error in testIndPois : wrong input of xIndex or csIndex"))
-    results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+    results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
   
   xIndex = unique(xIndex);
   csIndex = unique(csIndex);
-  #extract the data
   x = dataset[ , xIndex];
   cs = dataset[ , csIndex];
-  #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if ( length(cs) != 0 ) {
     if ( is.null(dim(cs)[2]) ) { #cs is a vector
@@ -50,7 +46,7 @@ waldGamma = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
           stat_hash[[key]] <- 0;   #.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
         }
-        results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+        results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
         return(results);
       }
     } else { #more than one var
@@ -60,7 +56,7 @@ waldGamma = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
             stat_hash[[key]] <- 0;  #.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- log(1);   #.set(pvalue_hash , key , 1)
           }
-          results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+          results <- list(pvalue = log(1), stat = 0, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
           return(results);
         }
       }
@@ -79,18 +75,16 @@ waldGamma = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo = NU
     stat = mod[pr, 3]^2 / summary(fit)[[ 14 ]]
     pvalue = pchisq( stat, 1, lower.tail = FALSE, log.p = TRUE ) 
   }	
-  flag = 1;
   if ( is.na(pvalue) || is.na(stat) ) {
     pvalue = log(1);
     stat = 0;
-    flag = 0;
   } else {
     if (hash) {
       stat_hash[[key]] <- stat;     #.set(stat_hash , key , stat)
       pvalue_hash[[key]] <- pvalue;       #.set(pvalue_hash , key , pvalue)
     }
   }
-  results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
+  results <- list(pvalue = pvalue, stat = stat, stat_hash=stat_hash, pvalue_hash=pvalue_hash);
   return(results);
   
 }
\ No newline at end of file
