@@ -10,8 +10,8 @@ library(dplyr)
 ### ~ ~ ~ Load The Dataset ~ ~ ~ ###
 wine.url <- "ftp://ftp.ics.uci.edu/pub/machine-learning-databases/wine/wine.data"
 wine <- read.csv(wine.url,
-                 check.names = F,
-                 header = F) 
+                 check.names = FALSE,
+                 header = FALSE) 
 head(wine)
 str(wine)
 colnames(wine) <- c('Type', 'Alcohol', 'Malic', 'Ash', 
